/*	$NetBSD: msg_134.c,v 1.3 2022/06/16 16:58:36 rillig Exp $	*/
# 3 "msg_134.c"

// Test for message: conversion of pointer to '%s' may lose bits [134]

/* expect+1: error: syntax error ':' [249] */
TODO: "Add example code that triggers the above message."
TODO: "Add example code that almost triggers the above message."
